about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--clippy_lints/src/panic_in_result.rs26
-rw-r--r--src/lintlist/mod.rs2
-rw-r--r--tests/ui/panic_in_result.rs22
-rw-r--r--tests/ui/panic_in_result.stderr60
4 files changed, 32 insertions, 78 deletions
diff --git a/src/lintlist/mod.rs b/src/lintlist/mod.rs
index b4f20ca7f14..1f56c56f081 100644
--- a/src/lintlist/mod.rs
+++ b/src/lintlist/mod.rs
@@ -1707,7 +1707,7 @@ pub static ref ALL_LINTS: Vec<Lint> = vec![
     Lint {
         name: "panic_in_result",
         group: "restriction",
-        desc: "functions of type `Result<..>` / `Option`<...> that contain `panic!()` or `unreachable()` or `unimplemented()` ",
+        desc: "functions of type `Result<..>` that contain `panic!()`, `todo!()` or `unreachable()` or `unimplemented()` ",
         deprecation: None,
         module: "panic_in_result",
     },
diff --git a/tests/ui/panic_in_result.rs b/tests/ui/panic_in_result.rs
index 21e9efca87b..056778995a4 100644
--- a/tests/ui/panic_in_result.rs
+++ b/tests/ui/panic_in_result.rs
@@ -18,19 +18,9 @@ impl A {
         unreachable!();
     }
 
-    fn option_with_unreachable() -> Option<bool> // should emit lint
+    fn result_with_todo() -> Result<bool, String> // should emit lint
     {
-        unreachable!();
-    }
-
-    fn option_with_unimplemented() -> Option<bool> // should emit lint
-    {
-        unimplemented!();
-    }
-
-    fn option_with_panic() -> Option<bool> // should emit lint
-    {
-        panic!("error");
+        todo!("Finish this");
     }
 
     fn other_with_panic() // should not emit lint
@@ -48,14 +38,14 @@ impl A {
         unimplemented!();
     }
 
-    fn result_without_banned_functions() -> Result<bool, String> // should not emit lint
+    fn other_with_todo() // should not emit lint
     {
-        Ok(true)
+        todo!("finish this")
     }
 
-    fn option_without_banned_functions() -> Option<bool> // should not emit lint
+    fn result_without_banned_functions() -> Result<bool, String> // should not emit lint
     {
-        Some(true)
+        Ok(true)
     }
 }
 
diff --git a/tests/ui/panic_in_result.stderr b/tests/ui/panic_in_result.stderr
index 74273bd9abb..3b9ac69f20d 100644
--- a/tests/ui/panic_in_result.stderr
+++ b/tests/ui/panic_in_result.stderr
@@ -1,4 +1,4 @@
-error: used unimplemented, unreachable or panic in a function that returns result or option
+error: used unimplemented, unreachable, todo or panic in a function that returns result
   --> $DIR/panic_in_result.rs:6:5
    |
 LL | /     fn result_with_panic() -> Result<bool, String> // should emit lint
@@ -8,7 +8,7 @@ LL | |     }
    | |_____^
    |
    = note: `-D clippy::panic-in-result` implied by `-D warnings`
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
+   = help: unimplemented, unreachable, todo or panic should not be used in a function that returns result
 note: will cause the application to crash.
   --> $DIR/panic_in_result.rs:8:9
    |
@@ -16,7 +16,7 @@ LL |         panic!("error");
    |         ^^^^^^^^^^^^^^^^
    = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
 
-error: used unimplemented, unreachable or panic in a function that returns result or option
+error: used unimplemented, unreachable, todo or panic in a function that returns result
   --> $DIR/panic_in_result.rs:11:5
    |
 LL | /     fn result_with_unimplemented() -> Result<bool, String> // should emit lint
@@ -25,7 +25,7 @@ LL | |         unimplemented!();
 LL | |     }
    | |_____^
    |
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
+   = help: unimplemented, unreachable, todo or panic should not be used in a function that returns result
 note: will cause the application to crash.
   --> $DIR/panic_in_result.rs:13:9
    |
@@ -33,7 +33,7 @@ LL |         unimplemented!();
    |         ^^^^^^^^^^^^^^^^^
    = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
 
-error: used unimplemented, unreachable or panic in a function that returns result or option
+error: used unimplemented, unreachable, todo or panic in a function that returns result
   --> $DIR/panic_in_result.rs:16:5
    |
 LL | /     fn result_with_unreachable() -> Result<bool, String> // should emit lint
@@ -42,7 +42,7 @@ LL | |         unreachable!();
 LL | |     }
    | |_____^
    |
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
+   = help: unimplemented, unreachable, todo or panic should not be used in a function that returns result
 note: will cause the application to crash.
   --> $DIR/panic_in_result.rs:18:9
    |
@@ -50,56 +50,22 @@ LL |         unreachable!();
    |         ^^^^^^^^^^^^^^^
    = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
 
-error: used unimplemented, unreachable or panic in a function that returns result or option
+error: used unimplemented, unreachable, todo or panic in a function that returns result
   --> $DIR/panic_in_result.rs:21:5
    |
-LL | /     fn option_with_unreachable() -> Option<bool> // should emit lint
+LL | /     fn result_with_todo() -> Result<bool, String> // should emit lint
 LL | |     {
-LL | |         unreachable!();
+LL | |         todo!("Finish this");
 LL | |     }
    | |_____^
    |
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
+   = help: unimplemented, unreachable, todo or panic should not be used in a function that returns result
 note: will cause the application to crash.
   --> $DIR/panic_in_result.rs:23:9
    |
-LL |         unreachable!();
-   |         ^^^^^^^^^^^^^^^
-   = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
-
-error: used unimplemented, unreachable or panic in a function that returns result or option
-  --> $DIR/panic_in_result.rs:26:5
-   |
-LL | /     fn option_with_unimplemented() -> Option<bool> // should emit lint
-LL | |     {
-LL | |         unimplemented!();
-LL | |     }
-   | |_____^
-   |
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
-note: will cause the application to crash.
-  --> $DIR/panic_in_result.rs:28:9
-   |
-LL |         unimplemented!();
-   |         ^^^^^^^^^^^^^^^^^
-   = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
-
-error: used unimplemented, unreachable or panic in a function that returns result or option
-  --> $DIR/panic_in_result.rs:31:5
-   |
-LL | /     fn option_with_panic() -> Option<bool> // should emit lint
-LL | |     {
-LL | |         panic!("error");
-LL | |     }
-   | |_____^
-   |
-   = help: unimplemented, unreachable or panic should not be used in a function that returns result or option
-note: will cause the application to crash.
-  --> $DIR/panic_in_result.rs:33:9
-   |
-LL |         panic!("error");
-   |         ^^^^^^^^^^^^^^^^
+LL |         todo!("Finish this");
+   |         ^^^^^^^^^^^^^^^^^^^^^
    = note: this error originates in a macro (in Nightly builds, run with -Z macro-backtrace for more info)
 
-error: aborting due to 6 previous errors
+error: aborting due to 4 previous errors
diff --git a/clippy_lints/src/panic_in_result.rs b/clippy_lints/src/panic_in_result.rs
index 239b4bdbdb1..2901f393fc6 100644
--- a/clippy_lints/src/panic_in_result.rs
+++ b/clippy_lints/src/panic_in_result.rs
@@ -7,16 +7,16 @@ use rustc_session::{declare_lint_pass, declare_tool_lint};
 use rustc_span::Span;
 
 declare_clippy_lint! {
     /// **What it does:** Checks for usage of `panic!`, `unimplemented!` or `unreachable!` in a function of type result/option.
     ///
-    /// **Why is this bad?** For some codebases, it is desirable for functions of type option/result to return an error instead of crashing. Hence unimplemented, panic and unreachable should be avoided.
+    /// **Why is this bad?** For some codebases, it is desirable for functions of type result to return an error instead of crashing. Hence unimplemented, panic and unreachable should be avoided.
     ///
     /// **Known problems:** None.
     ///
     /// **Example:**
     ///
     /// ```rust
-    /// fn option_with_panic() -> Option<bool>
+    /// fn result_with_panic() -> Result<bool, String>
     /// {
     ///     panic!("error");
     /// }
@@ -24,7 +24,7 @@ declare_clippy_lint! {
 
     pub PANIC_IN_RESULT,
     restriction,
-    "functions of type `Result<..>` / `Option`<...> that contain `panic!()` or `unreachable()` or `unimplemented()` "
+    "functions of type `Result<..>` that contain `panic!()`, `todo!()` or `unreachable()` or `unimplemented()` "
 }
 
 declare_lint_pass!(PanicInResult => [PANIC_IN_RESULT]);
@@ -35,8 +35,7 @@ impl<'tcx> LateLintPass<'tcx> for PanicInResult {
             // first check if it's a method or function
             if let hir::ImplItemKind::Fn(ref _signature, _) = impl_item.kind;
             // checking if its return type is `result` or `option`
-            if is_type_diagnostic_item(cx, return_ty(cx, impl_item.hir_id), sym!(result_type))
-                || is_type_diagnostic_item(cx, return_ty(cx, impl_item.hir_id), sym!(option_type));
+            if is_type_diagnostic_item(cx, return_ty(cx, impl_item.hir_id), sym!(result_type));
             then {
                 lint_impl_body(cx, impl_item.span, impl_item);
             }
@@ -55,14 +54,13 @@ impl<'tcx> Visitor<'tcx> for FindPanicUnimplementedUnreachable {
     type Map = Map<'tcx>;
 
     fn visit_expr(&mut self, expr: &'tcx Expr<'_>) {
-        if is_expn_of(expr.span, "unimplemented").is_some() {
-            self.result.push(expr.span);
-        } else if is_expn_of(expr.span, "unreachable").is_some() {
-            self.result.push(expr.span);
-        } else if is_expn_of(expr.span, "panic").is_some() {
+        if is_expn_of(expr.span, "unimplemented").is_some()
+            || is_expn_of(expr.span, "unreachable").is_some()
+            || is_expn_of(expr.span, "panic").is_some()
+            || is_expn_of(expr.span, "todo").is_some()
+        {
             self.result.push(expr.span);
         }
-
         // and check sub-expressions
         intravisit::walk_expr(self, expr);
     }
@@ -88,10 +86,10 @@ fn lint_impl_body<'tcx>(cx: &LateContext<'tcx>, impl_span: Span, impl_item: &'tc
                     cx,
                     PANIC_IN_RESULT,
                     impl_span,
-                    "used unimplemented, unreachable or panic in a function that returns result or option",
+                    "used unimplemented, unreachable, todo or panic in a function that returns result",
                     move |diag| {
                         diag.help(
-                            "unimplemented, unreachable or panic should not be used in a function that returns result or option" );
+                            "unimplemented, unreachable, todo or panic should not be used in a function that returns result" );
                         diag.span_note(fpu.result, "will cause the application to crash.");
                     });
             }
@@ -7,16 +7,16 @@ use rustc_session::{declare_lint_pass, declare_tool_lint};
 
 declare_clippy_lint! {
-    /// **What it does:** Checks for usage of `panic!`, `unimplemented!` or `unreachable!` in a function of type result/option.
+    /// **What it does:** Checks for usage of `panic!`, `unimplemented!`, `todo!` or `unreachable!` in a function of type result.
     ///